@@ -20,8 +20,6 @@ import (
 const collectorURL = "https://collect.traefik.io/9vxmmkcdmalbdi635d4jgc5p5rx0h7h8"
 
 // Collected data.
-//
-//nolint:musttag // cannot be changed for historical reasons.
 type data struct {
 	Version       string
 	Codename      string
@@ -67,7 +65,7 @@ func createBody(staticConfiguration *static.Configuration) (*bytes.Buffer, error
 	}
 
 	buf := new(bytes.Buffer)
-	err = json.NewEncoder(buf).Encode(data)
+	err = json.NewEncoder(buf).Encode(data) //nolint:musttag // cannot be changed for historical reasons.
 	if err != nil {
 		return nil, err
 	}
