@@ -7,11 +7,13 @@ import (
 	"net/http"
 	"os"
 	"strings"
+	"testing"
 	"time"
 
-	"github.com/go-check/check"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
+	"github.com/stretchr/testify/suite"
 	"github.com/traefik/traefik/v2/integration/try"
-	checker "github.com/vdemeester/shakers"
 )
 
 // HealthCheck test suites.
@@ -23,287 +25,272 @@ type HealthCheckSuite struct {
 	whoami4IP string
 }
 
-func (s *HealthCheckSuite) SetUpSuite(c *check.C) {
-	s.createComposeProject(c, "healthcheck")
-	s.composeUp(c)
-
-	s.whoami1IP = s.getComposeServiceIP(c, "whoami1")
-	s.whoami2IP = s.getComposeServiceIP(c, "whoami2")
-	s.whoami3IP = s.getComposeServiceIP(c, "whoami3")
-	s.whoami4IP = s.getComposeServiceIP(c, "whoami4")
+func TestHealthCheckSuite(t *testing.T) {
+	suite.Run(t, new(HealthCheckSuite))
 }
 
-func (s *HealthCheckSuite) TestSimpleConfiguration(c *check.C) {
-	file := s.adaptFile(c, "fixtures/healthcheck/simple.toml", struct {
+func (s *HealthCheckSuite) SetupSuite() {
+	s.BaseSuite.SetupSuite()
+
+	s.createComposeProject("healthcheck")
+	s.composeUp()
+
+	s.whoami1IP = s.getComposeServiceIP("whoami1")
+	s.whoami2IP = s.getComposeServiceIP("whoami2")
+	s.whoami3IP = s.getComposeServiceIP("whoami3")
+	s.whoami4IP = s.getComposeServiceIP("whoami4")
+}
+
+func (s *HealthCheckSuite) TearDownSuite() {
+	s.BaseSuite.TearDownSuite()
+}
+
+func (s *HealthCheckSuite) TestSimpleConfiguration() {
+	file := s.adaptFile("fixtures/healthcheck/simple.toml", struct {
 		Server1 string
 		Server2 string
 	}{s.whoami1IP, s.whoami2IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// wait for traefik
-	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
+	require.NoError(s.T(), err)
 
 	frontendHealthReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontendHealthReq.Host = "test.localhost"
 
 	err = try.Request(frontendHealthReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Fix all whoami health to 500
 	client := &http.Client{}
 	whoamiHosts := []string{s.whoami1IP, s.whoami2IP}
 	for _, whoami := range whoamiHosts {
 		statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+whoami+"/health", bytes.NewBufferString("500"))
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 		_, err = client.Do(statusInternalServerErrorReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 	}
 
 	// Verify no backend service is available due to failing health checks
 	err = try.Request(frontendHealthReq, 3*time.Second, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Change one whoami health to 200
 	statusOKReq1, err := http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("200"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusOKReq1)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Verify frontend health : after
 	err = try.Request(frontendHealthReq, 3*time.Second, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	frontendReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontendReq.Host = "test.localhost"
 
 	// Check if whoami1 responds
 	err = try.Request(frontendReq, 500*time.Millisecond, try.BodyContains(s.whoami1IP))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Check if the service with bad health check (whoami2) never respond.
 	err = try.Request(frontendReq, 2*time.Second, try.BodyContains(s.whoami2IP))
-	c.Assert(err, checker.NotNil)
+	assert.Error(s.T(), err)
 
 	// TODO validate : run on 80
 	resp, err := http.Get("http://127.0.0.1:8000/")
 
 	// Expected a 404 as we did not configure anything
-	c.Assert(err, checker.IsNil)
-	c.Assert(resp.StatusCode, checker.Equals, http.StatusNotFound)
+	require.NoError(s.T(), err)
+	assert.Equal(s.T(), http.StatusNotFound, resp.StatusCode)
 }
 
-func (s *HealthCheckSuite) TestMultipleEntrypoints(c *check.C) {
-	file := s.adaptFile(c, "fixtures/healthcheck/multiple-entrypoints.toml", struct {
+func (s *HealthCheckSuite) TestMultipleEntrypoints() {
+	file := s.adaptFile("fixtures/healthcheck/multiple-entrypoints.toml", struct {
 		Server1 string
 		Server2 string
 	}{s.whoami1IP, s.whoami2IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// Wait for traefik
-	err = try.GetRequest("http://localhost:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
+	require.NoError(s.T(), err)
 
 	// Check entrypoint http1
 	frontendHealthReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontendHealthReq.Host = "test.localhost"
 
-	err = try.Request(frontendHealthReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	err = try.Request(frontendHealthReq, 5*time.Second, try.StatusCodeIs(http.StatusOK))
+	require.NoError(s.T(), err)
 
 	// Check entrypoint http2
 	frontendHealthReq, err = http.NewRequest(http.MethodGet, "http://127.0.0.1:9000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontendHealthReq.Host = "test.localhost"
 
-	err = try.Request(frontendHealthReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	err = try.Request(frontendHealthReq, 5*time.Second, try.StatusCodeIs(http.StatusOK))
+	require.NoError(s.T(), err)
 
 	// Set the both whoami health to 500
 	client := &http.Client{}
 	whoamiHosts := []string{s.whoami1IP, s.whoami2IP}
 	for _, whoami := range whoamiHosts {
 		statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+whoami+"/health", bytes.NewBufferString("500"))
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 		_, err = client.Do(statusInternalServerErrorReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 	}
 
 	// Verify no backend service is available due to failing health checks
 	err = try.Request(frontendHealthReq, 5*time.Second, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// reactivate the whoami2
 	statusInternalServerOkReq, err := http.NewRequest(http.MethodPost, "http://"+s.whoami2IP+"/health", bytes.NewBufferString("200"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusInternalServerOkReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	frontend1Req, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontend1Req.Host = "test.localhost"
 
 	frontend2Req, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:9000/", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontend2Req.Host = "test.localhost"
 
 	// Check if whoami1 never responds
 	err = try.Request(frontend2Req, 2*time.Second, try.BodyContains(s.whoami1IP))
-	c.Assert(err, checker.NotNil)
+	assert.Error(s.T(), err)
 
 	// Check if whoami1 never responds
 	err = try.Request(frontend1Req, 2*time.Second, try.BodyContains(s.whoami1IP))
-	c.Assert(err, checker.NotNil)
+	assert.Error(s.T(), err)
 }
 
-func (s *HealthCheckSuite) TestPortOverload(c *check.C) {
+func (s *HealthCheckSuite) TestPortOverload() {
 	// Set one whoami health to 200
 	client := &http.Client{}
 	statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("200"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusInternalServerErrorReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
-	file := s.adaptFile(c, "fixtures/healthcheck/port_overload.toml", struct {
+	file := s.adaptFile("fixtures/healthcheck/port_overload.toml", struct {
 		Server1 string
 	}{s.whoami1IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err = cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// wait for traefik
 	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 10*time.Second, try.BodyContains("Host(`test.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	frontendHealthReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	frontendHealthReq.Host = "test.localhost"
 
 	// We test bad gateway because we use an invalid port for the backend
 	err = try.Request(frontendHealthReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusBadGateway))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Set one whoami health to 500
 	statusInternalServerErrorReq, err = http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("500"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusInternalServerErrorReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Verify no backend service is available due to failing health checks
 	err = try.Request(frontendHealthReq, 3*time.Second, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 }
 
 // Checks if all the loadbalancers created will correctly update the server status.
-func (s *HealthCheckSuite) TestMultipleRoutersOnSameService(c *check.C) {
-	file := s.adaptFile(c, "fixtures/healthcheck/multiple-routers-one-same-service.toml", struct {
+func (s *HealthCheckSuite) TestMultipleRoutersOnSameService() {
+	file := s.adaptFile("fixtures/healthcheck/multiple-routers-one-same-service.toml", struct {
 		Server1 string
 	}{s.whoami1IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// wait for traefik
-	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`test.localhost`)"))
+	require.NoError(s.T(), err)
 
 	// Set whoami health to 200 to be sure to start with the wanted status
 	client := &http.Client{}
 	statusOkReq, err := http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("200"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusOkReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// check healthcheck on web1 entrypoint
 	healthReqWeb1, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	healthReqWeb1.Host = "test.localhost"
 	err = try.Request(healthReqWeb1, 1*time.Second, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// check healthcheck on web2 entrypoint
 	healthReqWeb2, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:9000/health", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	healthReqWeb2.Host = "test.localhost"
 
 	err = try.Request(healthReqWeb2, 500*time.Millisecond, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Set whoami health to 500
 	statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("500"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusInternalServerErrorReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Verify no backend service is available due to failing health checks
 	err = try.Request(healthReqWeb1, 3*time.Second, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	err = try.Request(healthReqWeb2, 3*time.Second, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Change one whoami health to 200
 	statusOKReq1, err := http.NewRequest(http.MethodPost, "http://"+s.whoami1IP+"/health", bytes.NewBufferString("200"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusOKReq1)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Verify health check
 	err = try.Request(healthReqWeb1, 3*time.Second, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	err = try.Request(healthReqWeb2, 3*time.Second, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 }
 
-func (s *HealthCheckSuite) TestPropagate(c *check.C) {
-	file := s.adaptFile(c, "fixtures/healthcheck/propagate.toml", struct {
+func (s *HealthCheckSuite) TestPropagate() {
+	file := s.adaptFile("fixtures/healthcheck/propagate.toml", struct {
 		Server1 string
 		Server2 string
 		Server3 string
 		Server4 string
 	}{s.whoami1IP, s.whoami2IP, s.whoami3IP, s.whoami4IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// wait for traefik
-	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`root.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`root.localhost`)"))
+	require.NoError(s.T(), err)
 
 	rootReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	rootReq.Host = "root.localhost"
 
 	err = try.Request(rootReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusOK))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Bring whoami1 and whoami3 down
 	client := http.Client{
@@ -313,9 +300,9 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 	whoamiHosts := []string{s.whoami1IP, s.whoami3IP}
 	for _, whoami := range whoamiHosts {
 		statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+whoami+"/health", bytes.NewBufferString("500"))
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 		_, err = client.Do(statusInternalServerErrorReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 	}
 
 	try.Sleep(time.Second)
@@ -327,19 +314,19 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 	reachedServers := make(map[string]int)
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(rootReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		if reachedServers[s.whoami4IP] > reachedServers[s.whoami2IP] {
-			c.Assert(string(body), checker.Contains, want2)
+			assert.Contains(s.T(), string(body), want2)
 			reachedServers[s.whoami2IP]++
 			continue
 		}
 
 		if reachedServers[s.whoami2IP] > reachedServers[s.whoami4IP] {
-			c.Assert(string(body), checker.Contains, want4)
+			assert.Contains(s.T(), string(body), want4)
 			reachedServers[s.whoami4IP]++
 			continue
 		}
@@ -356,48 +343,48 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 		}
 	}
 
-	c.Assert(reachedServers[s.whoami2IP], checker.Equals, 2)
-	c.Assert(reachedServers[s.whoami4IP], checker.Equals, 2)
+	assert.Equal(s.T(), 2, reachedServers[s.whoami2IP])
+	assert.Equal(s.T(), 2, reachedServers[s.whoami4IP])
 
 	fooReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	fooReq.Host = "foo.localhost"
 
 	// Verify load-balancing on foo still works, and that we're getting wsp2, wsp2, wsp2, wsp2, etc.
 	want := `IP: ` + s.whoami2IP
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(fooReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
-		c.Assert(string(body), checker.Contains, want)
+		assert.Contains(s.T(), string(body), want)
 	}
 
 	barReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	barReq.Host = "bar.localhost"
 
 	// Verify load-balancing on bar still works, and that we're getting wsp2, wsp2, wsp2, wsp2, etc.
 	want = `IP: ` + s.whoami2IP
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(barReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
-		c.Assert(string(body), checker.Contains, want)
+		assert.Contains(s.T(), string(body), want)
 	}
 
 	// Bring whoami2 and whoami4 down
 	whoamiHosts = []string{s.whoami2IP, s.whoami4IP}
 	for _, whoami := range whoamiHosts {
 		statusInternalServerErrorReq, err := http.NewRequest(http.MethodPost, "http://"+whoami+"/health", bytes.NewBufferString("500"))
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 		_, err = client.Do(statusInternalServerErrorReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 	}
 
 	try.Sleep(time.Second)
@@ -405,25 +392,25 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 	// Verify that everything is down, and that we get 503s everywhere.
 	for i := 0; i < 2; i++ {
 		resp, err := client.Do(rootReq)
-		c.Assert(err, checker.IsNil)
-		c.Assert(resp.StatusCode, checker.Equals, http.StatusServiceUnavailable)
+		require.NoError(s.T(), err)
+		assert.Equal(s.T(), http.StatusServiceUnavailable, resp.StatusCode)
 
 		resp, err = client.Do(fooReq)
-		c.Assert(err, checker.IsNil)
-		c.Assert(resp.StatusCode, checker.Equals, http.StatusServiceUnavailable)
+		require.NoError(s.T(), err)
+		assert.Equal(s.T(), http.StatusServiceUnavailable, resp.StatusCode)
 
 		resp, err = client.Do(barReq)
-		c.Assert(err, checker.IsNil)
-		c.Assert(resp.StatusCode, checker.Equals, http.StatusServiceUnavailable)
+		require.NoError(s.T(), err)
+		assert.Equal(s.T(), http.StatusServiceUnavailable, resp.StatusCode)
 	}
 
 	// Bring everything back up.
 	whoamiHosts = []string{s.whoami1IP, s.whoami2IP, s.whoami3IP, s.whoami4IP}
 	for _, whoami := range whoamiHosts {
 		statusOKReq, err := http.NewRequest(http.MethodPost, "http://"+whoami+"/health", bytes.NewBufferString("200"))
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 		_, err = client.Do(statusOKReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 	}
 
 	try.Sleep(time.Second)
@@ -432,10 +419,10 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 	reachedServers = make(map[string]int)
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(rootReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		if strings.Contains(string(body), `IP: `+s.whoami1IP) {
 			reachedServers[s.whoami1IP]++
@@ -458,19 +445,19 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 		}
 	}
 
-	c.Assert(reachedServers[s.whoami1IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami2IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami3IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami4IP], checker.Equals, 1)
+	assert.Equal(s.T(), 1, reachedServers[s.whoami1IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami2IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami3IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami4IP])
 
 	// Verify everything is up on foo router.
 	reachedServers = make(map[string]int)
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(fooReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		if strings.Contains(string(body), `IP: `+s.whoami1IP) {
 			reachedServers[s.whoami1IP]++
@@ -493,19 +480,19 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 		}
 	}
 
-	c.Assert(reachedServers[s.whoami1IP], checker.Equals, 2)
-	c.Assert(reachedServers[s.whoami2IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami3IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami4IP], checker.Equals, 0)
+	assert.Equal(s.T(), 2, reachedServers[s.whoami1IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami2IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami3IP])
+	assert.Equal(s.T(), 0, reachedServers[s.whoami4IP])
 
 	// Verify everything is up on bar router.
 	reachedServers = make(map[string]int)
 	for i := 0; i < 4; i++ {
 		resp, err := client.Do(barReq)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
+		require.NoError(s.T(), err)
 
 		if strings.Contains(string(body), `IP: `+s.whoami1IP) {
 			reachedServers[s.whoami1IP]++
@@ -528,102 +515,87 @@ func (s *HealthCheckSuite) TestPropagate(c *check.C) {
 		}
 	}
 
-	c.Assert(reachedServers[s.whoami1IP], checker.Equals, 2)
-	c.Assert(reachedServers[s.whoami2IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami3IP], checker.Equals, 1)
-	c.Assert(reachedServers[s.whoami4IP], checker.Equals, 0)
+	assert.Equal(s.T(), 2, reachedServers[s.whoami1IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami2IP])
+	assert.Equal(s.T(), 1, reachedServers[s.whoami3IP])
+	assert.Equal(s.T(), 0, reachedServers[s.whoami4IP])
 }
 
-func (s *HealthCheckSuite) TestPropagateNoHealthCheck(c *check.C) {
-	file := s.adaptFile(c, "fixtures/healthcheck/propagate_no_healthcheck.toml", struct {
+func (s *HealthCheckSuite) TestPropagateNoHealthCheck() {
+	file := s.adaptFile("fixtures/healthcheck/propagate_no_healthcheck.toml", struct {
 		Server1 string
 	}{s.whoami1IP})
-	defer os.Remove(file)
 
-	cmd, display := s.traefikCmd(withConfigFile(file))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(file))
 
 	// wait for traefik
-	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`noop.localhost`)"), try.BodyNotContains("Host(`root.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`noop.localhost`)"), try.BodyNotContains("Host(`root.localhost`)"))
+	require.NoError(s.T(), err)
 
 	rootReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	rootReq.Host = "root.localhost"
 
 	err = try.Request(rootReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusNotFound))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 }
 
-func (s *HealthCheckSuite) TestPropagateReload(c *check.C) {
+func (s *HealthCheckSuite) TestPropagateReload() {
 	// Setup a WSP service without the healthcheck enabled (wsp-service1)
-	withoutHealthCheck := s.adaptFile(c, "fixtures/healthcheck/reload_without_healthcheck.toml", struct {
+	withoutHealthCheck := s.adaptFile("fixtures/healthcheck/reload_without_healthcheck.toml", struct {
 		Server1 string
 		Server2 string
 	}{s.whoami1IP, s.whoami2IP})
-	defer os.Remove(withoutHealthCheck)
-	withHealthCheck := s.adaptFile(c, "fixtures/healthcheck/reload_with_healthcheck.toml", struct {
+	withHealthCheck := s.adaptFile("fixtures/healthcheck/reload_with_healthcheck.toml", struct {
 		Server1 string
 		Server2 string
 	}{s.whoami1IP, s.whoami2IP})
-	defer os.Remove(withHealthCheck)
 
-	cmd, display := s.traefikCmd(withConfigFile(withoutHealthCheck))
-	defer display(c)
-	err := cmd.Start()
-	c.Assert(err, checker.IsNil)
-	defer s.killCmd(cmd)
+	s.traefikCmd(withConfigFile(withoutHealthCheck))
 
 	// wait for traefik
-	err = try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`root.localhost`)"))
-	c.Assert(err, checker.IsNil)
+	err := try.GetRequest("http://127.0.0.1:8080/api/rawdata", 60*time.Second, try.BodyContains("Host(`root.localhost`)"))
+	require.NoError(s.T(), err)
 
 	// Allow one of the underlying services on it to fail all servers HC (whoami2)
 	client := http.Client{
 		Timeout: 10 * time.Second,
 	}
 	statusOKReq, err := http.NewRequest(http.MethodPost, "http://"+s.whoami2IP+"/health", bytes.NewBufferString("500"))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = client.Do(statusOKReq)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	rootReq, err := http.NewRequest(http.MethodGet, "http://127.0.0.1:8000", nil)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	rootReq.Host = "root.localhost"
 
 	// Check the failed service (whoami2) is getting requests, but answer 500
 	err = try.Request(rootReq, 500*time.Millisecond, try.StatusCodeIs(http.StatusServiceUnavailable))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	// Enable the healthcheck on the root WSP (wsp-service1) and let Traefik reload the config
 	fr1, err := os.OpenFile(withoutHealthCheck, os.O_APPEND|os.O_WRONLY, 0o644)
-	c.Assert(fr1, checker.NotNil)
-	c.Assert(err, checker.IsNil)
+	assert.NotNil(s.T(), fr1)
+	require.NoError(s.T(), err)
 	err = fr1.Truncate(0)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
 	fr2, err := os.ReadFile(withHealthCheck)
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	_, err = fmt.Fprint(fr1, string(fr2))
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 	err = fr1.Close()
-	c.Assert(err, checker.IsNil)
+	require.NoError(s.T(), err)
 
-	try.Sleep(1 * time.Second)
+	// Waiting for the reflected change.
+	err = try.Request(rootReq, 5*time.Second, try.StatusCodeIs(http.StatusOK))
+	require.NoError(s.T(), err)
 
 	// Check the failed service (whoami2) is not getting requests
 	wantIPs := []string{s.whoami1IP, s.whoami1IP, s.whoami1IP, s.whoami1IP}
 	for _, ip := range wantIPs {
-		want := "IP: " + ip
-		resp, err := client.Do(rootReq)
-		c.Assert(err, checker.IsNil)
-
-		body, err := io.ReadAll(resp.Body)
-		c.Assert(err, checker.IsNil)
-
-		c.Assert(string(body), checker.Contains, want)
+		err = try.Request(rootReq, 5*time.Second, try.StatusCodeIs(http.StatusOK), try.BodyContains("IP: "+ip))
+		require.NoError(s.T(), err)
 	}
 }
