@@ -2,8 +2,11 @@ package service
 
 import (
 	"context"
+	"io"
 	"net/http"
 	"net/http/httptest"
+	"net/http/httptrace"
+	"net/textproto"
 	"strings"
 	"testing"
 
@@ -89,24 +92,34 @@ func TestGetLoadBalancerServiceHandler(t *testing.T) {
 	server1 := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("X-From", "first")
 	}))
-	defer server1.Close()
+	t.Cleanup(server1.Close)
 
 	server2 := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("X-From", "second")
 	}))
-	defer server2.Close()
+	t.Cleanup(server2.Close)
 
 	serverPassHost := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("X-From", "passhost")
 		assert.Equal(t, "callme", r.Host)
 	}))
-	defer serverPassHost.Close()
+	t.Cleanup(serverPassHost.Close)
 
 	serverPassHostFalse := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("X-From", "passhostfalse")
 		assert.NotEqual(t, "callme", r.Host)
 	}))
-	defer serverPassHostFalse.Close()
+	t.Cleanup(serverPassHostFalse.Close)
+
+	hasNoUserAgent := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		assert.Empty(t, r.Header.Get("User-Agent"))
+	}))
+	t.Cleanup(hasNoUserAgent.Close)
+
+	hasUserAgent := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		assert.Equal(t, "foobar", r.Header.Get("User-Agent"))
+	}))
+	t.Cleanup(hasUserAgent.Close)
 
 	type ExpectedResult struct {
 		StatusCode     int
@@ -122,6 +135,7 @@ func TestGetLoadBalancerServiceHandler(t *testing.T) {
 		service          *dynamic.ServersLoadBalancer
 		responseModifier func(*http.Response) error
 		cookieRawValue   string
+		userAgent        string
 
 		expected []ExpectedResult
 	}{
@@ -286,6 +300,39 @@ func TestGetLoadBalancerServiceHandler(t *testing.T) {
 				},
 			},
 		},
+		{
+			desc:        "No user-agent",
+			serviceName: "test",
+			service: &dynamic.ServersLoadBalancer{
+				Servers: []dynamic.Server{
+					{
+						URL: hasNoUserAgent.URL,
+					},
+				},
+			},
+			expected: []ExpectedResult{
+				{
+					StatusCode: http.StatusOK,
+				},
+			},
+		},
+		{
+			desc:        "Custom user-agent",
+			serviceName: "test",
+			userAgent:   "foobar",
+			service: &dynamic.ServersLoadBalancer{
+				Servers: []dynamic.Server{
+					{
+						URL: hasUserAgent.URL,
+					},
+				},
+			},
+			expected: []ExpectedResult{
+				{
+					StatusCode: http.StatusOK,
+				},
+			},
+		},
 	}
 
 	for _, test := range testCases {
@@ -297,6 +344,12 @@ func TestGetLoadBalancerServiceHandler(t *testing.T) {
 			assert.NotNil(t, handler)
 
 			req := testhelpers.MustNewRequest(http.MethodGet, "http://callme", nil)
+			assert.Equal(t, "", req.Header.Get("User-Agent"))
+
+			if test.userAgent != "" {
+				req.Header.Set("User-Agent", test.userAgent)
+			}
+
 			if test.cookieRawValue != "" {
 				req.Header.Set("Cookie", test.cookieRawValue)
 			}
@@ -335,6 +388,96 @@ func TestGetLoadBalancerServiceHandler(t *testing.T) {
 	}
 }
 
+// This test is an adapted version of net/http/httputil.Test1xxResponses test.
+func Test1xxResponses(t *testing.T) {
+	sm := NewManager(nil, nil, nil, &RoundTripperManager{
+		roundTrippers: map[string]http.RoundTripper{
+			"default@internal": http.DefaultTransport,
+		},
+	})
+
+	backend := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		h := w.Header()
+		h.Add("Link", "</style.css>; rel=preload; as=style")
+		h.Add("Link", "</script.js>; rel=preload; as=script")
+		w.WriteHeader(http.StatusEarlyHints)
+
+		h.Add("Link", "</foo.js>; rel=preload; as=script")
+		w.WriteHeader(http.StatusProcessing)
+
+		_, _ = w.Write([]byte("Hello"))
+	}))
+	t.Cleanup(backend.Close)
+
+	config := &dynamic.ServersLoadBalancer{
+		Servers: []dynamic.Server{
+			{
+				URL: backend.URL,
+			},
+		},
+	}
+	handler, err := sm.getLoadBalancerServiceHandler(context.Background(), "foobar", config)
+	assert.NoError(t, err)
+
+	frontend := httptest.NewServer(handler)
+	t.Cleanup(frontend.Close)
+	frontendClient := frontend.Client()
+
+	checkLinkHeaders := func(t *testing.T, expected, got []string) {
+		t.Helper()
+
+		if len(expected) != len(got) {
+			t.Errorf("Expected %d link headers; got %d", len(expected), len(got))
+		}
+
+		for i := range expected {
+			if i >= len(got) {
+				t.Errorf("Expected %q link header; got nothing", expected[i])
+
+				continue
+			}
+
+			if expected[i] != got[i] {
+				t.Errorf("Expected %q link header; got %q", expected[i], got[i])
+			}
+		}
+	}
+
+	var respCounter uint8
+	trace := &httptrace.ClientTrace{
+		Got1xxResponse: func(code int, header textproto.MIMEHeader) error {
+			switch code {
+			case http.StatusEarlyHints:
+				checkLinkHeaders(t, []string{"</style.css>; rel=preload; as=style", "</script.js>; rel=preload; as=script"}, header["Link"])
+			case http.StatusProcessing:
+				checkLinkHeaders(t, []string{"</style.css>; rel=preload; as=style", "</script.js>; rel=preload; as=script", "</foo.js>; rel=preload; as=script"}, header["Link"])
+			default:
+				t.Error("Unexpected 1xx response")
+			}
+
+			respCounter++
+
+			return nil
+		},
+	}
+	req, _ := http.NewRequestWithContext(httptrace.WithClientTrace(context.Background(), trace), http.MethodGet, frontend.URL, nil)
+
+	res, err := frontendClient.Do(req)
+	assert.NoError(t, err)
+
+	defer res.Body.Close()
+
+	if respCounter != 2 {
+		t.Errorf("Expected 2 1xx responses; got %d", respCounter)
+	}
+	checkLinkHeaders(t, []string{"</style.css>; rel=preload; as=style", "</script.js>; rel=preload; as=script", "</foo.js>; rel=preload; as=script"}, res.Header["Link"])
+
+	body, _ := io.ReadAll(res.Body)
+	if string(body) != "Hello" {
+		t.Errorf("Read body %q; want Hello", body)
+	}
+}
+
 func TestManager_Build(t *testing.T) {
 	testCases := []struct {
 		desc         string
